@@ -1,13 +1,13 @@
 import time
 
 
-def timeit(func):
-    def timeit_wrapper(*args, **kwargs):
+def timeit(func: callable):
+    def inner(*args, **kwargs):
         start_time = time.perf_counter()
         result = func(*args, **kwargs)
         end_time = time.perf_counter()
         total_time = end_time - start_time
-        print(f"\nFunction {func.__name__}{args} Took {total_time:.4f} seconds")
+        print(f"\nFunction {func.__name__} took {total_time:.4f} seconds")
         return result
 
-    return timeit_wrapper
+    return inner
